@@ -1,26 +1,13 @@
-/*****************************************************************************
- * This file is part of Kiten, a KDE Japanese Reference Tool...              *
- * Copyright (C) 2001 Jason Katz-Brown <jason@katzbrown.com>                 *
- * Copyright (C) 2005 Paul Temple <paul.temple@gmx.net>                      *
- * Copyright (C) 2006 Joseph Kerian <jkerian@gmail.com>                      *
- * Copyright (C) 2006 Eric Kjeldergaard <kjelderg@gmail.com>                 *
- * Copyright (C) 2011 Daniel E. Moctezuma <democtezuma@gmail.com>            *
- *                                                                           *
- * This program is free software; you can redistribute it and/or modify      *
- * it under the terms of the GNU General Public License as published by      *
- * the Free Software Foundation; either version 2 of the License, or         *
- * (at your option) any later version.                                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program; if not, write to the Free Software               *
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 *
- * USA                                                                       *
- *****************************************************************************/
+/*
+    This file is part of Kiten, a KDE Japanese Reference Tool...
+    SPDX-FileCopyrightText: 2001 Jason Katz-Brown <jason@katzbrown.com>
+    SPDX-FileCopyrightText: 2005 Paul Temple <paul.temple@gmx.net>
+    SPDX-FileCopyrightText: 2006 Joseph Kerian <jkerian@gmail.com>
+    SPDX-FileCopyrightText: 2006 Eric Kjeldergaard <kjelderg@gmail.com>
+    SPDX-FileCopyrightText: 2011 Daniel E. Moctezuma <democtezuma@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kiten.h"
 
@@ -81,8 +68,8 @@ Kiten::Kiten( QWidget *parent, const char *name )
   (void) Accel->insert(   "Lookup English/Japanese word"
                         , i18n("Lookup English/Japanese Word")
                         , i18n( "Looks up current text on clipboard in the same way as if you used Kiten's regular search." )
-                        , Qt::CTRL + Qt::ALT + Qt::Key_S
-                        , Qt::CTRL + Qt::ALT + Qt::Key_S
+                        , Qt::CTRL | Qt::ALT | Qt::Key_S
+                        , Qt::CTRL | Qt::ALT | Qt::Key_S
                         , this
                         , SLOT(searchClipboardContents()) );
   Accel->readSettings( KSharedConfig::openConfig() );
@@ -115,6 +102,7 @@ Kiten::Kiten( QWidget *parent, const char *name )
   _sysTrayIcon->setStandardActionsEnabled(true);
   _sysTrayIcon->setAssociatedWidget(this);
   _sysTrayIcon->setIconByName(QStringLiteral("kiten"));
+  _sysTrayIcon->setStatus(KStatusNotifierItem::Active);
 
   /* Set things as they were (as told in the config) */
   _autoSearchToggle->setChecked( _config->autosearch() );
